This crate provides high-level APIs for accessing components provided by Immersive Engineering and Immersive Technology.
As a general rule, APIs in this crate accept an Invoker and a Buffer scratch buffer, the
latter being used for encoding parameters and decoding return values. This buffer can be reused
between API calls to reduce heap allocations. In some cases the return value of an API may
borrow from the scratch buffer.
Features
- The
allocfeature enables APIs that require dynamic memory allocation. - The
stdfeature enables integration with the Rust standard library that can only be done outsideno_stdmode, and also enablesalloc.
Important
You must depend on oc-wasm-futures with the
proper-waker feature in your own application if your chosen executor requires the
proper-waker feature.
Modules
- common
- Data types that are used by more than one Immersive machine.
- engineering
- Provides high-level access to Immersive Engineering APIs.
- error
- Provides an error type used for higher level calls.
- prelude
- Provides symbols that virtually all consumers will want to import all of.
- technology
- Provides high-level access to Immersive Technology APIs.